summaryrefslogtreecommitdiff
path: root/lib/mkmf.rb
diff options
context:
space:
mode:
authorJeremy Evans <code@jeremyevans.net>2019-07-07 20:16:57 -0700
committerJeremy Evans <code@jeremyevans.net>2019-07-23 07:57:38 -0700
commit325f7b6008a4a10e9b0f1c69ee4518b0669461be (patch)
tree19706b1f862027865e95cf32142e30dd4b867705 /lib/mkmf.rb
parentb6f07f748a95f1d5dc0d21e821320564776c744d (diff)
Make pkg_config in mkmf include -I cflags in return value
This was the historical behavior, it was modified unintentionally by 097c3e9cbbf23718371f08c24b2d2297b039f63f, which started storing these flags in a different global variable. Also, include the incflags when logging, and document that the method modifies $INCFLAGS. Fixes [Bug #10651]
Diffstat (limited to 'lib/mkmf.rb')
-rw-r--r--lib/mkmf.rb8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/mkmf.rb b/lib/mkmf.rb
index bf95484aa8..692ceb43a9 100644
--- a/lib/mkmf.rb
+++ b/lib/mkmf.rb
@@ -1801,7 +1801,7 @@ SRC
#
# Where {option} is, for instance, <code>--cflags</code>.
#
# The values obtained are appended to +$CFLAGS+, +$LDFLAGS+ and
# +$libs+.
#
# If an <code>option</code> argument is given, the config command is
@@ -1857,9 +1857,9 @@ SRC
$LDFLAGS = [orig_ldflags, ldflags].join(' ')
Logging::message "package configuration for %s\n", pkg
- Logging::message "cflags: %s\nldflags: %s\nlibs: %s\n\n",
- cflags, ldflags, libs
- [cflags, ldflags, libs]
+ Logging::message "incflags: %s\ncflags: %s\nldflags: %s\nlibs: %s\n\n",
+ incflags, cflags, ldflags, libs
+ [[incflags, cflags].join(' '), ldflags, libs]
else
Logging::message "package configuration for %s is not found\n", pkg
nil
@@ -1801,7 +1801,7 @@ SRC
# Where {option} is, for instance, <code>--cflags</code>.
#
- # The values obtained are appended to +$CFLAGS+, +$LDFLAGS+ and
+ # The values obtained are appended to +$INCFLAGS+, +$CFLAGS+, +$LDFLAGS+ and
# +$libs+.
#